/*
** Copyright (C) 1993-2013 Mark B. Hanson (mbh@panix.com)
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2, or (at your option)
** any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// @(#)$Id: buzzer.h 1344 2013-04-05 21:18:39Z mark $

#ifdef	XSC_BUZZER_H

class Buzzer;

#else	// XSC_BUZZER_H
#define	XSC_BUZZER_H

#include "castle.h"
#include "king.h"
#include "laser.h"
#include "ship.h"
#include "stats.h"
#include "xything.h"

class Buzzer : public virtual Xything {
private:
    bool flying;
    float *randomizer;
    bool *riding_on;		// number of rings
    float speed;
    bool paused;

    void set_randomizer(void);

public:
    Buzzer(void);
    ~Buzzer(void);

    void render(const bool);

    void move(Castle *, Ship *);
    void launch(King *, Castle *);
    bool hit(Laser *);
    void set_xpoints(void);
    void upgrade(Castle *);
    void resize(const int, const int);

    bool alive(void) const;
    void snuff(void);
    void pause(const bool);
};


inline bool
Buzzer::alive(void) const
{
    return flying;
} // Buzzer::alive


inline void
Buzzer::snuff(void)
{
    flying = false;
} // Buzzer::snuff


inline void
Buzzer::pause(const bool pause_state)
{
    paused = pause_state;
} // Buzzer::pause

#endif	// XSC_BUZZER_H
