/*
** Copyright (C) 1993-2013 Mark B. Hanson (mbh@panix.com)
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2, or (at your option)
** any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// @(#)$Id: ring.h 1344 2013-04-05 21:18:39Z mark $

#ifdef	XSC_RING_H

class Ring;

#else	// XSC_RING_H
#define	XSC_RING_H

#include "laser.h"
#include "stats.h"
#include "tthing.h"

typedef enum _hitstatus {
    RING_DULL,
    RING_BRIGHT,
    RING_DEAD
} hitstatus;


class Ring : public Tthing {
private:
    hitstatus *hits;
    int numsegments;
    unsigned int value;
    GC *gcs;

    int which_seg(const float) const;

public:
    Ring(const float, const float, const unsigned int,
	    const GC *const, const int);
    ~Ring(void);

    void render(const bool);

    void seg_center(const float, float *const, float *const) const;
    bool hit(Laser *, Stats *);
    int remaining(void) const;
    bool hole(const float) const;
    void refresh(void);

    unsigned int get_value(void) const;
    void set_value(const unsigned int);
    void set_gc(const int, const GC);
};


inline unsigned int
Ring::get_value(void) const
{
    return value;
} // Ring::get_value


inline void
Ring::set_value(const unsigned int v)
{
    value = v;
} // Ring::set_value


inline void
Ring::set_gc(const int i, const GC ngc)
{
    gcs[i] = ngc;
} // Ring::set_gc

#endif	// XSC_RING_H
